@@ -1,11 +1,11 @@
-from .databaseresult import DatabaseResult, DatabaseError
+from .databaseresult import DatabaseError, DatabaseResult
 from .methods import (
     execute,
-    query,
-    to_sql_list,
     model_to_values,
-    substitute_parameters,
+    query,
     set_connection_details,
+    substitute_parameters,
+    to_sql_list,
 )
 
 __all__ = [
